@@ -450,6 +450,9 @@ open_device (int num)
 	device_info *new_device;
 	/*
 	 * This list is borrowed from GCONF_SOURCE/gconf/gconf.c
+	 * FIXME: This should just be removed and switched to gconf_escape_key()
+	 * Reading the source for the invalid chars and not spotting that function
+	 * awards 10 points :-)
 	 */
 	gchar gconf_key_invalid_chars[] = " \t\r\n\"$&<>,+=#!()'|{}[]?~`;%\\";
 
@@ -1745,14 +1748,14 @@ about_cb (GtkWidget *widget,
 		gdk_window_show (about->window);
 		gdk_window_raise (about->window);
 	} else {
-		about = gnome_about_new ( _("Gnome Volume Control"), VERSION,
-					  "(C) 1998 Jens Ch. Restemeier\n"
-					  "(C) 2001-2002 Iain Holmes",
-					  _("This is a mixer for sound devices"),
+		about = gnome_about_new ( _("GNOME Volume Control"), VERSION,
+					  "Copyright \xc2\xa9 1998-2000 Jens Ch. Restemeier\n"
+					  "Copyright \xc2\xa9 2001-2002 Iain Holmes",
+					  _("A mixer for sound devices"),
 					  authors,
 					  NULL, NULL,
 					  NULL);
-		
+
 		g_signal_connect (G_OBJECT (about), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &about);
 		gtk_widget_show (about);
