@@ -15,9 +15,10 @@
 #include <gtk/gtkrange.h>
 #include <gtk/gtkbutton.h>
 #include <gtk/gtkoptionmenu.h>
-
+#include <gtk/gtkmessagedialog.h> 
 #include <libgnome/gnome-i18n.h>
 #include <libgnomeui/gnome-about.h>
+#include <libgnome/gnome-help.h>
 
 #include <bonobo/bonobo-exception.h>
 #include <bonobo/bonobo-control.h>
@@ -43,7 +44,7 @@ maybe_close_tray (GnomeCD *gcd)
 	if (gnome_cdrom_get_status (gcd->cdrom, &status, &error) == FALSE) {
 		gcd_warning ("%s", error);
 		g_error_free (error);
-		
+		g_free (status);
 		return;
 	}
 
@@ -95,6 +96,7 @@ play_cb (GtkButton *button,
 	if (gnome_cdrom_get_status (gcd->cdrom, &status, &error) == FALSE) {
 		gcd_warning ("%s", error);
 		g_error_free (error);
+		g_free (status);
 		return;
 
 	}
@@ -452,7 +454,8 @@ set_window_track_title (GnomeCD *gcd,
 	const char *track_name = "";
 
 	if (gcd->disc_info) {
-		if (idx >= 0 && idx < gcd->disc_info->ntracks)
+		if (idx >= 0 && idx < gcd->disc_info->ntracks &&
+		    gcd->disc_info->track_info)
 			track_name = gcd->disc_info->track_info [idx]->name;
 
 		artist = gcd->disc_info->artist ? gcd->disc_info->artist : "";
@@ -522,6 +525,18 @@ status_ok (GnomeCD *gcd,
 		g_free (text);
 		set_window_track_title (gcd, status);
 			
+		/* Update the tray icon tooltip */
+		if (gcd->disc_info != NULL) {
+			text = g_strdup_printf (_("Playing %s - %s"),
+						gcd->disc_info->artist ? gcd->disc_info->artist : _("Unknown Artist"),
+						gcd->disc_info->title ? gcd->disc_info->title : _("Unknown Album"));
+		} else {
+			text = g_strdup (_("Playing"));
+		}
+		
+		gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, text, NULL);
+		g_free (text);
+		
 		break;
 
 	case GNOME_CDROM_AUDIO_PAUSE:
@@ -537,6 +552,9 @@ status_ok (GnomeCD *gcd,
 		}
 
 		set_window_track_title (gcd, status);
+
+		/* Update the tray icon tooltip */
+		gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, _("Paused"), NULL);
 		break;
 		
 	case GNOME_CDROM_AUDIO_COMPLETE:
@@ -579,6 +597,9 @@ status_ok (GnomeCD *gcd,
 			}
 
 			set_track_option_menu (GTK_OPTION_MENU (gcd->tracks), 1);
+
+			/* Update tray icon tooltip */
+			gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, _("CD Player"), NULL);
 		}		
 		break;
 		
@@ -594,6 +615,9 @@ status_ok (GnomeCD *gcd,
 		} else {
 			gnome_cd_set_window_title (gcd, NULL, NULL);
 		}
+
+		/* Update the tray icon tooltip */
+		gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, _("Stopped"), NULL);
 		break;
 		
 	case GNOME_CDROM_AUDIO_ERROR:
@@ -608,6 +632,9 @@ status_ok (GnomeCD *gcd,
 		} else {
 			gnome_cd_set_window_title (gcd, NULL, NULL);
 		}
+
+		/* Update the tray icon tooltip */
+		gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, _("No disc"), NULL);
 		break;
 		
 	default:
@@ -760,6 +787,9 @@ cd_status_changed_cb (GnomeCDRom *cdrom,
 		cd_display_clear (CD_DISPLAY (gcd->display));
                 cd_display_set_line (CD_DISPLAY (gcd->display), CD_DISPLAY_LINE_TIME, _("No Cdrom"));
                 gnome_cd_set_window_title (gcd, NULL, NULL);
+
+		/* Updated the tray icon tooltip */
+		gtk_tooltips_set_tip (gcd->tray_tips, gcd->tray, _("No Cdrom"), NULL);
                 break;
 
 	default:
@@ -787,12 +817,12 @@ about_cb (GtkWidget *widget,
 	  gpointer data)
 {
 	static GtkWidget *about = NULL;
-	const char *authors[2] = {"Iain Holmes", NULL};
+	const char *authors[2] = {"Iain Holmes <iain@prettypeople.org>", NULL};
 	
 	if (about == NULL) {
-		about = gnome_about_new ("Gnome CD", VERSION,
-					 _("Copyright (C) 2001, 2002"),
-					 _("A GNOME cd player"),
+		about = gnome_about_new (_("CD Player"), VERSION,
+					 "Copyright \xc2\xa9 2001-2002 Iain Holmes",
+					 _("A CD player for GNOME"),
 					 authors, NULL, NULL, NULL);
 		g_signal_connect (G_OBJECT (about), "destroy",
 				  G_CALLBACK (gtk_widget_destroyed), &about);
@@ -800,6 +830,29 @@ about_cb (GtkWidget *widget,
 	}
 }
 
+void
+help_cb (GtkWidget *widget,
+	 gpointer data)
+{
+	GError *error = NULL;
+
+	gnome_help_display ("gnome-cd", NULL, &error); 
+	if (error) {
+		GtkWidget *msgbox;
+		msgbox = gtk_message_dialog_new (NULL,
+						 GTK_DIALOG_MODAL,
+						 GTK_MESSAGE_ERROR,
+						 GTK_BUTTONS_CLOSE,
+						 ("There was an error displaying help: \n%s"),
+						 error->message);
+		g_signal_connect (G_OBJECT(msgbox), "response",
+				  G_CALLBACK (gtk_widget_destroy),
+				  NULL);
+		gtk_widget_show (msgbox);
+		g_error_free (error);
+	} 
+}
+ 
 void
 loopmode_changed_cb (GtkWidget *display,
 		     GnomeCDRomMode mode,
@@ -816,6 +869,22 @@ playmode_changed_cb (GtkWidget *display,
 	gcd->cdrom->playmode = mode;
 }
 
+gboolean
+tray_icon_clicked (GtkWidget *widget, GdkEventButton *event, GnomeCD *gcd)
+{
+	if (event->button != 3) {
+		if (GTK_WIDGET_VISIBLE (gcd->window)) {
+			gtk_widget_hide (gcd->window);
+		} else {
+			gtk_widget_show (gcd->window);
+		}
+
+		return TRUE;
+	} else {
+		return FALSE;
+	}
+}
+
 void
 open_preferences (GtkWidget *widget,
 		  GnomeCD *gcd)
